import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

interface Controlable {
	public void step();
}

class Control {
	public static final int DELAY = 100;
	private JFrame f;
	private Controlable ctrl;
	
	private enum State { WAIT, RUN };
	private State state;
	
	private RunStep run;
	
	Control(Controlable c) {
		ctrl = c;
		state = State.WAIT;
		
		f = new JFrame("Control");
		f.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		JButton bStep = new JButton("1 step");
		f.add(bStep, BorderLayout.NORTH);
		
		JPanel pRun = new JPanel();
		f.add(pRun, BorderLayout.SOUTH);
		JButton bRun = new JButton("Run");
		pRun.add(bRun);
		JButton bStop = new JButton("Stop");
		pRun.add(bStop);
		
		bStep.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) { if (state == State.WAIT) ctrl.step(); }
		});
		
		bStop.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					if (state == State.RUN) run.interrupt();
					state = State.WAIT;
				}
		});
		
		bRun.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					if (state == State.WAIT) {
						run = new RunStep();
						state = State.RUN;
						run.start();
					}
				}
		});
		
		f.pack();
		f.setVisible(true);
	}
	
	private class RunStep extends Thread {
		private boolean end = false;
		
		public void run() {
			while (!end) {
				ctrl.step();
				try {
					Thread.sleep(DELAY);
				} catch (InterruptedException e) { end = true; }
			}
		}
	}
}

