import java.awt.*;
import javax.swing.*;

class World extends JFrame {
	public static final long serialVersionUID = 0;
	
	public static final int CELL_SIZE = 20;
	
	private WorldCanvas worldCanvas;
	
	World(String[][] m) {
		super("World");
		
		worldCanvas = new WorldCanvas();
		add(worldCanvas, BorderLayout.CENTER);
		
		display(m);
		
		int dimX = 30 + m[0].length * World.CELL_SIZE + 2;
		int dimY = 30 + m.length * World.CELL_SIZE + 2;
		setSize(dimX, dimY);
		
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		setVisible(true);
	}
	
	void display(String[][] m) {
		int dimX = 30 + m[0].length * World.CELL_SIZE + 2;
		int dimY = 30 + m.length * World.CELL_SIZE + 2;
		setSize(dimX, dimY);
		
		worldCanvas.display(m);
	}
	
	private class WorldCanvas extends JPanel {
		public static final long serialVersionUID = 0;
		private String[][] mat;
		
		void display(String[][] m) {
			mat = m;
			repaint();
		}
		
		private void drawGrid(Graphics g) {
			g.setColor(Color.black);
			int Xmax = mat[0].length * World.CELL_SIZE + 1;
			int Ymax = mat.length * World.CELL_SIZE + 1;
			for (int c = 0; c < mat[0].length; c++)
				g.drawLine(c * World.CELL_SIZE, 0, c * World.CELL_SIZE, Ymax);
			g.drawLine(Xmax, 0, Xmax, Ymax);
			for (int l = 0; l < mat.length; l++)
				g.drawLine(0, l * World.CELL_SIZE, Xmax, l * World.CELL_SIZE);
			g.drawLine(0, Ymax, Xmax, Ymax);
		}
		
		private void drawBlock(Graphics g, int c, int l) {
			g.setColor(Color.black);
			g.fillRect(c * World.CELL_SIZE, l * World.CELL_SIZE, World.CELL_SIZE, World.CELL_SIZE);
		}
		
		private void drawPiege(Graphics g, int c, int l) {
			g.setColor(Color.gray);
			g.fillRect(c * World.CELL_SIZE, l * World.CELL_SIZE, World.CELL_SIZE, World.CELL_SIZE);
		}
		
		private void drawTelep(Graphics g, int c, int l) {
			g.setColor(Color.pink);
			g.fillRect(c * World.CELL_SIZE, l * World.CELL_SIZE, World.CELL_SIZE, World.CELL_SIZE);
		}
		
		private void drawRobot(Graphics g, int c, int l, String color) {
			g.setColor(getColor(color));
			g.fillOval(c * World.CELL_SIZE + 3, l * World.CELL_SIZE + 3, World.CELL_SIZE - 6, World.CELL_SIZE - 6);
		}
		
		public void paintComponent(Graphics g) {
			int dimX = mat[0].length * World.CELL_SIZE + 2;
			int dimY = mat.length * World.CELL_SIZE + 2;
			g.setColor(Color.white);
			g.fillRect(0, 0, dimX, dimY);
			
			drawGrid(g);
			for (int c = 0; c < mat[0].length; c++) {
				for (int l = 0; l < mat.length; l++) {
					if (mat[l][c].equals("block")) drawBlock(g, c, l);
					else if (mat[l][c].equals("piege")) drawPiege(g, c, l);
					else if (mat[l][c].equals("telep")) drawTelep(g, c, l);
					else if (mat[l][c].equals("empty"));
					else drawRobot(g, c, l, mat[l][c]);
				}
			}
		}
		
		private Color getColor(String name) {
			if (name.equals("black")) return Color.black;
			if (name.equals("blue")) return Color.blue;
			if (name.equals("cyan")) return Color.cyan;
			if (name.equals("gray")) return Color.gray;
			if (name.equals("green")) return Color.green;
			if (name.equals("magenta")) return Color.magenta;
			if (name.equals("orange")) return Color.orange;
			if (name.equals("pink")) return Color.pink;
			if (name.equals("red")) return Color.red;
			if (name.equals("white")) return Color.white;
			if (name.equals("yellow")) return Color.yellow;
			return Color.black;
		}
	}
}
